@@ -2,49 +2,49 @@ use strict;
 use warnings;
 package Postfix::Parse::Mailq;
 # ABSTRACT: parse the output of the postfix mailq command
-$Postfix::Parse::Mailq::VERSION = '1.004';
+$Postfix::Parse::Mailq::VERSION = '1.005';
 use Mixin::Linewise::Readers -readers;
 
-# =head1 SYNOPSIS
-#
-#   use Postfix::Parse::Mailq;
-#
-#   my $mailq_output = `mailq`;
-#   my $entries = Postfix::Parse::Mailq->read_string($mailq_output);
-#
-#   my $bytes = 0;
-#   for my $entry (@$entries) {
-#     next unless grep { /\@aol.com$/ } @{ $entry->{remaining_rcpts} };
-#     $bytes += $entry->{size};
-#   }
-#   
-#   print "$bytes bytes remain to send to AOL destinations\n";
-#
-# =head1 WARNING
-#
-# This code is really rough and the interface will change.  Entries will be
-# objects.  There will be some more methods.  Still, the basics are likely to
-# keep working, or keep pretty close to what you see here now.
-#
-# =method read_file
-#
-# =method read_handle
-#
-# =method read_string
-#
-#   my $entries = Postfix::Parse::Mailq->read_string($string, \%arg);
-#
-# This methods read the output of postfix's F<mailq> from a file (by name), a
-# filehandle, or a string, respectively.  They return an arrayref of hashrefs,
-# each hashref representing one entry in the queue as reported by F<mailq>.
-#
-# Valid arguments are:
-#
-#   spool - a hashref of { queue_id -> spool_name } pairs
-#           if given, this will be used to attempt to indicate in which
-#           spool messages currently are; it is not entirely reliable (race!)
-#
-# =cut
+#pod =head1 SYNOPSIS
+#pod
+#pod   use Postfix::Parse::Mailq;
+#pod
+#pod   my $mailq_output = `mailq`;
+#pod   my $entries = Postfix::Parse::Mailq->read_string($mailq_output);
+#pod
+#pod   my $bytes = 0;
+#pod   for my $entry (@$entries) {
+#pod     next unless grep { /\@aol.com$/ } @{ $entry->{remaining_rcpts} };
+#pod     $bytes += $entry->{size};
+#pod   }
+#pod   
+#pod   print "$bytes bytes remain to send to AOL destinations\n";
+#pod
+#pod =head1 WARNING
+#pod
+#pod This code is really rough and the interface will change.  Entries will be
+#pod objects.  There will be some more methods.  Still, the basics are likely to
+#pod keep working, or keep pretty close to what you see here now.
+#pod
+#pod =method read_file
+#pod
+#pod =method read_handle
+#pod
+#pod =method read_string
+#pod
+#pod   my $entries = Postfix::Parse::Mailq->read_string($string, \%arg);
+#pod
+#pod This methods read the output of postfix's F<mailq> from a file (by name), a
+#pod filehandle, or a string, respectively.  They return an arrayref of hashrefs,
+#pod each hashref representing one entry in the queue as reported by F<mailq>.
+#pod
+#pod Valid arguments are:
+#pod
+#pod   spool - a hashref of { queue_id -> spool_name } pairs
+#pod           if given, this will be used to attempt to indicate in which
+#pod           spool messages currently are; it is not entirely reliable (race!)
+#pod
+#pod =cut
 
 sub read_handle {
   my ($self, $handle, $arg) = @_;
@@ -82,14 +82,14 @@ sub read_handle {
   return \@entries;
 }
 
-# =method parse_block
-#
-#   my $entry = Mailq->parse_block(\@lines);
-#
-# Given all the lines in a single entry's block of lines in mailq output, this
-# returns data about the entry.
-#
-# =cut
+#pod =method parse_block
+#pod
+#pod   my $entry = Mailq->parse_block(\@lines);
+#pod
+#pod Given all the lines in a single entry's block of lines in mailq output, this
+#pod returns data about the entry.
+#pod
+#pod =cut
 
 my %STATUS_FOR = (
   '!' => 'held',
@@ -101,9 +101,10 @@ sub parse_block {
 
   chomp @$block;
   my $first = shift @$block;
-  my $error = defined $block->[0] && $block->[0] =~ /\A\S/
+  my $error = defined $block->[0] && ($block->[0] =~ /\A\S/ || $block->[0] =~ /\A\s+\(/)
             ? (shift @$block)
             : undef;
+  $error =~ s/\A\s+// if defined $error;
   my @dest  = map { s/^\s+//; $_; } @$block;
 
   my ($qid, $status_chr, $size, $date, $sender) = $first =~ m/
@@ -146,7 +147,7 @@ Postfix::Parse::Mailq - parse the output of the postfix mailq command
 
 =head1 VERSION
 
-version 1.004
+version 1.005
 
 =head1 SYNOPSIS
 
@@ -200,9 +201,15 @@ keep working, or keep pretty close to what you see here now.
 
 Ricardo SIGNES <rjbs@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Johan Carlquist
+
+Johan Carlquist <jocar@su.se>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2015 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
